@@ -1,12 +1,14 @@
 ## generate data
 # example is not high-dimensional to keep computation time low
+library("mvtnorm")
 set.seed(1234)  # for reproducibility
 n <- 100  # number of observations
 p <- 25   # number of variables
 beta <- rep.int(c(1, 0), c(5, p-5))  # coefficients
 sigma <- 0.5      # controls signal-to-noise ratio
 epsilon <- 0.1    # contamination level
-x <- replicate(p, rnorm(n))     # predictor matrix
+Sigma <- 0.5^t(sapply(1:p, function(i, j) abs(i-j), 1:p))
+x <- rmvnorm(n, sigma=Sigma)    # predictor matrix
 e <- rnorm(n)                   # error terms
 i <- 1:ceiling(epsilon*n)       # observations to be contaminated
 e[i] <- e[i] + 5                # vertical outliers
@@ -14,4 +16,4 @@ y <- c(x %*% beta + sigma * e)  # response
 x[i,] <- x[i,] + 5              # bad leverage points
 
 ## fit robust LARS model
-rlars(x, y)
+rlars(x, y, sMax = 10)
